pub enum ComplexMetricError {
ShapeMismatch {
reference: (usize, usize),
estimate: (usize, usize),
},
MaskShapeMismatch {
actual: (usize, usize),
expected: (usize, usize),
},
EmptyMask,
UnsupportedScalar {
input: &'static str,
},
NonFinite {
input: &'static str,
},
ZeroReferenceNormalization {
metric: &'static str,
},
ZeroEstimateNormalization {
metric: &'static str,
},
DegenerateAlignment {
alignment: ComplexAlignment,
reason: &'static str,
},
}Expand description
Errors returned by explicit-alignment complex-image metrics.
Variants
ShapeMismatch
Reference and estimate have different (height, width) shapes.
Fields
MaskShapeMismatch
A selection mask does not match the field shape.
EmptyMask
No pixel was selected by the optional mask.
UnsupportedScalar
A generic complex component could not be represented as f64.
NonFinite
An input contains a non-finite real or imaginary component.
ZeroReferenceNormalization
A relative metric has zero reference norm.
ZeroEstimateNormalization
A normalized correlation has zero aligned-estimate norm.
DegenerateAlignment
The selected alignment cannot be fitted to the selected pixels.
Fields

alignment: ComplexAlignmentRequested alignment mode.